==> zio-aws-mediatailor_3-5.17.103.1-sources.jar: zio/aws/mediatailor/model/DescribeSourceLocationRequest.scala <==
package zio.aws.mediatailor.model
import zio.aws.mediatailor.model.primitives.__string
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class DescribeSourceLocationRequest(sourceLocationName: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.mediatailor.model.DescribeSourceLocationRequest = {
    import DescribeSourceLocationRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.mediatailor.model.DescribeSourceLocationRequest
      .builder()
      .sourceLocationName(__string.unwrap(sourceLocationName): java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.mediatailor.model.DescribeSourceLocationRequest.ReadOnly =
    zio.aws.mediatailor.model.DescribeSourceLocationRequest
      .wrap(buildAwsValue())
}
object DescribeSourceLocationRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.mediatailor.model.DescribeSourceLocationRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.mediatailor.model.DescribeSourceLocationRequest =
      zio.aws.mediatailor.model
        .DescribeSourceLocationRequest(sourceLocationName)
    def sourceLocationName: __string
    def getSourceLocationName: ZIO[Any, Nothing, __string] =
      ZIO.succeed(sourceLocationName)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.mediatailor.model.DescribeSourceLocationRequest
  ) extends zio.aws.mediatailor.model.DescribeSourceLocationRequest.ReadOnly {
    override val sourceLocationName: __string =
      zio.aws.mediatailor.model.primitives.__string(impl.sourceLocationName())
  }
  def wrap(
      impl: software.amazon.awssdk.services.mediatailor.model.DescribeSourceLocationRequest
  ): zio.aws.mediatailor.model.DescribeSourceLocationRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-mediatailor_3-5.19.8.1-sources.jar: zio/aws/mediatailor/model/DescribeSourceLocationRequest.scala <==
package zio.aws.mediatailor.model
import zio.aws.mediatailor.model.primitives.__string
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class DescribeSourceLocationRequest(sourceLocationName: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.mediatailor.model.DescribeSourceLocationRequest = {
    import DescribeSourceLocationRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.mediatailor.model.DescribeSourceLocationRequest
      .builder()
      .sourceLocationName(sourceLocationName: java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.mediatailor.model.DescribeSourceLocationRequest.ReadOnly =
    zio.aws.mediatailor.model.DescribeSourceLocationRequest
      .wrap(buildAwsValue())
}
object DescribeSourceLocationRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.mediatailor.model.DescribeSourceLocationRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.mediatailor.model.DescribeSourceLocationRequest =
      zio.aws.mediatailor.model
        .DescribeSourceLocationRequest(sourceLocationName)
    def sourceLocationName: __string
    def getSourceLocationName: ZIO[Any, Nothing, __string] =
      ZIO.succeed(sourceLocationName)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.mediatailor.model.DescribeSourceLocationRequest
  ) extends zio.aws.mediatailor.model.DescribeSourceLocationRequest.ReadOnly {
    override val sourceLocationName: __string =
      impl.sourceLocationName(): __string
  }
  def wrap(
      impl: software.amazon.awssdk.services.mediatailor.model.DescribeSourceLocationRequest
  ): zio.aws.mediatailor.model.DescribeSourceLocationRequest.ReadOnly =
    new Wrapper(impl)
}
